﻿<%@ Page Language="C#" %>

<!DOCTYPE html>

<script runat="server">

    Ektron.Cms.Framework.Content.TemplateManager tManager = new Ektron.Cms.Framework.Content.TemplateManager();
    protected void Page_Load(object sender, EventArgs e)
    {
        //get a list of all templates
        Ektron.Cms.Common.TemplateCriteria tCriteria = new Ektron.Cms.Common.TemplateCriteria();
        tCriteria.AddFilter(Ektron.Cms.Common.TemplateDataProperty.Id, Ektron.Cms.Common.CriteriaFilterOperator.GreaterThan, 0);
        tCriteria.PagingInfo = new Ektron.Cms.PagingInfo(10000000);
        var templateList = tManager.GetList(tCriteria);
        //filter the list to only include pagebuilder templates
        templateList = templateList.Where(a => a.SubType == Ektron.Cms.Common.EkEnumeration.TemplateSubType.Wireframes).ToList();
        //if we want to regenerate all of the thumbnails at once. 
        if (!string.IsNullOrEmpty(Request.QueryString["regenAll"]))
        {
            UpdateTemplate(templateList);
            //get the list of templates again for display
            templateList = tManager.GetList(tCriteria);
            //filter the list to only include pagebuilder templates
            templateList = templateList.Where(a => a.SubType == Ektron.Cms.Common.EkEnumeration.TemplateSubType.Wireframes).ToList();
        }
        else if (!string.IsNullOrEmpty(Request.QueryString["tid"]))
        {
            UpdateTemplate(templateList.Where(a => a.Id == long.Parse(Request.QueryString["tid"])).ToList());
            //get the list of templates again for display
            templateList = tManager.GetList(tCriteria);
            //filter the list to only include pagebuilder templates
            templateList = templateList.Where(a => a.SubType == Ektron.Cms.Common.EkEnumeration.TemplateSubType.Wireframes).ToList();
        }
        templateItems.DataSource = templateList;
        templateItems.DataBind();
    }

    /// <summary>
    /// Updates the thumbnails for pagebuilder pages. May take a few moments to show up on the server after complete.
    /// </summary>
    /// <param name="ids"></param>
    private void UpdateTemplate(List<Ektron.Cms.TemplateData> templates)
    {
        //gets the template to update by ID
        foreach (var template in templates)
        {
            Ektron.Cms.PageBuilder.TemplateModel m_templateModel = new Ektron.Cms.PageBuilder.TemplateModel();
            //regenerate the thumbnail
            string strThumbnail = (string)(m_templateModel.GenerateThumbnail("/" + template.FileName));
            template.Thumbnail = strThumbnail;
            //update the thumbnail (will throw exception if you don't have permissions)
            tManager.Update(template);
        }
    }
</script>

<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
    <title>Regenerate pagebuilder template thumbnails</title>
</head>
<body>
    <form id="form1" runat="server">
        <h3>Regenerate a thumbnail for all or a particular pagebuilder template. Thumbnails may take a minute to populate in the website's uploaded images folder.
            <br />
            You must be logged in and have permissions to modify templates.</h3>
        <asp:Repeater ID="templateItems" runat="server">
            <HeaderTemplate>
                <a href="#regenAll" onclick="RegenThumb('regenAll');">Regenerate All</a>
                <table border="1">
                    <thead>
                        <tr>
                            <th>Template ID</th>
                            <th>Template Name</th>
                            <th>Template Thumbnail</th>
                            <th>Regen Thumbnail</th>
                        </tr>
                    </thead>
                    <tbody>
            </HeaderTemplate>
            <ItemTemplate>
                <tr>
                    <td><%#Eval("Id") %></td>
                    <td><%#Eval("TemplateName") %></td>
                    <td>
                        <img src='/uploadedimages/wireframesthumbnails/<%#Eval("Thumbnail") %>' /></td>
                    <td><a href="#Regen" onclick="RegenThumb('<%#Eval("Id")%>');">Regenerate</a></td>
                </tr>
            </ItemTemplate>
            <FooterTemplate>
                </tbody>
                </table>
            </FooterTemplate>
        </asp:Repeater>
        <script type="text/javascript">
            function RegenThumb(id) {
                if (id === 'regenAll') {
                    document.forms[0].action = window.location.pathname + '?regenAll=true';
                }
                else {
                    document.forms[0].action = window.location.pathname + '?tid=' + id;
                }
                document.forms[0].submit();
            }
        </script>
    </form>
</body>
</html>
